==> haskell-x509-validation-1.6.11-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-validation
version:              1.6.11
visibility:           public
id:                   x509-validation-1.6.11-JdNmOlbiClEBv2zcl7JsJ4
key:                  x509-validation-1.6.11-JdNmOlbiClEBv2zcl7JsJ4
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  fd740dc21ba241856b6e1ce40d2b658c
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-validation-1.6.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-validation-1.6.11
hs-libraries:         HSx509-validation-1.6.11-JdNmOlbiClEBv2zcl7JsJ4
depends:
    asn1-encoding-0.9.6-1hiEaDzNnvZCKkl9Gb4izO
    asn1-types-0.3.4-KHBfkOvXvyLC7EfnO8fkLD base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.29-19SjDRwWNox27CMfesQpq4
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    hourglass-0.2.12-3rdEguFqYyMGZvL0UmpBhl
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr mtl-2.2.2
    pem-0.2.4-KLN0tuS3ZoG84EBMFRxUqE x509-1.7.5-KZBg6E9cDNpzkDdONM3tO
    x509-store-1.6.7-GjMuzyM4405JwkexKUzc5E

haddock-interfaces:
    /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.11-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-validation
version:              1.6.11
visibility:           public
id:                   x509-validation-1.6.11-KMnTpvfp4wJpuZ3bqqSfN
key:                  x509-validation-1.6.11-KMnTpvfp4wJpuZ3bqqSfN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  37647e0fab1580fb4cab99a8c995f774
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-validation-1.6.11
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-validation-1.6.11
hs-libraries:         HSx509-validation-1.6.11-KMnTpvfp4wJpuZ3bqqSfN
depends:
    asn1-encoding-0.9.6-GST7u8YWSVMBlxeVag7x5g
    asn1-types-0.3.4-7gCtfa0duAqTepdsDJGVJ base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.29-GRn4QfSajtp4ejYMImOiTS
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC
    hourglass-0.2.12-1wkJ9BEKC60A2qbJDgDFCi
    memory-0.16.0-CGaPOmXCTce28vOCDDnDFr mtl-2.2.2
    pem-0.2.4-HYg3Jt06Zqq3C6bOo96L1R x509-1.7.5-HyBJj96t9GC2vaOmQQ4ozv
    x509-store-1.6.7-E1M1yu7n5ys7g0MI3dEOO3

haddock-interfaces:
    /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
